[pypy-svn] r75684 - in pypy/trunk/pypy/tool/release: . test

antocuni at codespeak.net antocuni at codespeak.net
Wed Jun 30 16:57:03 CEST 2010


Author: antocuni
Date: Wed Jun 30 16:57:01 2010
New Revision: 75684

Modified:
   pypy/trunk/pypy/tool/release/package.py
   pypy/trunk/pypy/tool/release/test/test_package.py
Log:
fix package.py to take the headers from trunk/include instead of fishing them
here and there. Also, make sure it also copies *.inl, which were ignored
before



Modified: pypy/trunk/pypy/tool/release/package.py
==============================================================================
--- pypy/trunk/pypy/tool/release/test/test_package.py	(original)
+++ pypy/trunk/pypy/tool/release/test/test_package.py	Wed Jun 30 16:57:01 2010
@@ -26,6 +26,9 @@
         assert prefix.join('README').check()
         th = tarfile.open(str(builddir.join('test.tar.bz2')))
         assert th.getmember('test/lib_pypy/syslog.py')
+        assert th.getmember('test/include/Python.h')
+        assert th.getmember('test/include/modsupport.inl')
+        assert th.getmember('test/include/pypy_decl.h')
     finally:
         if fake_pypy_c:
             pypy_c.remove()



More information about the Pypy-commit mailing list
--- pypy/trunk/pypy/tool/release/package.py	(original)
+++ pypy/trunk/pypy/tool/release/package.py	Wed Jun 30 16:57:01 2010
@@ -57,11 +57,11 @@
     for file in ['LICENSE', 'README']:
         shutil.copy(str(basedir.join(file)), str(pypydir))
     pypydir.ensure('include', dir=True)
     # we want to put there all *.h from module/cpyext/include
     # and from pypy/_interfaces
-    for n in basedir.join('pypy', 'module', 'cpyext', 'include').listdir('*.h'):
-        shutil.copy(str(n), str(pypydir.join('include')))
-    for n in basedir.join('pypy', '_interfaces').listdir('*.h'):
+    includedir = basedir.join('include')
+    headers = includedir.listdir('*.h') + includedir.listdir('*.inl')
+    for n in headers:
         shutil.copy(str(n), str(pypydir.join('include')))
     pypydir.ensure('bin', dir=True)
     archive_pypy_c = pypydir.join('bin', rename_pypy_c)
@@ -57,11 +57,11 @@
         shutil.copy(str(basedir.join(file)), str(pypydir))
     pypydir.ensure('include', dir=True)
-    # we want to put there all *.h from module/cpyext/include
+    # we want to put there all *.h and *.inl from trunk/include
     # and from pypy/_interfaces

Modified: pypy/trunk/pypy/tool/release/test/test_package.py
==============================================================================